# Yuki

[![Ask DeepWiki](https://deepwiki.com/badge.svg)](https://deepwiki.com/hepChern/Yuki)

Yuki is the Data Integration Thought Entity for the Chern Project. 

## Install:
+ Download the package
+ Run: python setup.py install

## Start:
+ yuki server start

## Stop:
+ Ctrl-C

